Commit in lcsim/src/org/lcsim/contrib/seedtracker on MAIN
MultipleScattering.java+4-31.5 -> 1.6
Update of multiple scatter map getter

lcsim/src/org/lcsim/contrib/seedtracker
MultipleScattering.java 1.5 -> 1.6
diff -u -r1.5 -r1.6
--- MultipleScattering.java	7 Feb 2008 18:20:50 -0000	1.5
+++ MultipleScattering.java	23 May 2008 16:11:03 -0000	1.6
@@ -43,8 +43,9 @@
     
     /**
      * Calculate the multiple scattering errors for a given helix.
      * The Helix pathmap is used to determine the x-y path length
      * from the DCA to the hits on the helix.
+     * 
      * @param helix HelicalTrackFit that we want the ms errors for
      * @return map containing the MultipleScatter objects for each hit
      */
@@ -54,7 +55,7 @@
         Map<HelicalTrackHit, MultipleScatter> msmap = new HashMap<HelicalTrackHit, MultipleScatter>();
         
         //  Retreive the x-y path lengths and calculate sin^2(theta) for this helix
-        Map<HelicalTrackHit, Double> pathmap = helix.pathmap();
+        Map<HelicalTrackHit, Double> pathmap = helix.getPathMap();
         double sth2 = Math.pow(helix.sth(), 2);
         
         //  Make sure all hits have x-y path lengths.  Hits added since the last fit
@@ -126,7 +127,7 @@
         
         //  Find the largest path length to a hit
         double smax = 0.;
-        for (Map.Entry<HelicalTrackHit, Double> mapentry : helix.pathmap().entrySet()) {
+        for (Map.Entry<HelicalTrackHit, Double> mapentry : helix.getPathMap().entrySet()) {
             smax = Math.max(smax, mapentry.getValue());
         }
         
@@ -43,8 +43,9 @@
     /**
      * Calculate the multiple scattering errors for a given helix.
-     * The Helix pathmap is used to determine the x-y path length
+     * The Helix getPathMap is used to determine the x-y path length
      * from the DCA to the hits on the helix.
CVSspam 0.2.8